@@ -62,8 +62,8 @@ subroutine FineED1(ED,Error,n,ncomp,spreadsigma,pars,&
   integer(kind=4),                   intent(out)::errorflag
   !
   ! Variables for subroutine kmeans
-  integer(kind=4),parameter::iter=20
-  integer(kind=4),parameter::nstart=100
+  integer(kind=4),parameter::iter=10
+  integer(kind=4),parameter::nstart=1000
   integer(kind=4)::belo(n),clusp(ncomp)
   real   (kind=8)::energ(ncomp),clust(ncomp)
   integer(kind=4)::ifault
@@ -122,7 +122,8 @@ subroutine FineED1(ED,Error,n,ncomp,spreadsigma,pars,&
     call kmeans(1,n,ncomp,iter,nstart,sED,&
                 belo,clust,clusp,energ,ifault)
     !
-    kpars(1,:)=1.0D+00/real(ncomp,kind=8)
+    !kpars(1,:)=1.0D+00/real(ncomp,kind=8)
+    kpars(1,:)=real(clusp,kind=8)/sum(clusp)
     kpars(2,:)=clust
     !
     call FMMED(sED,sError,n,ncomp,spreadsigma,&
